@@ -10,7 +10,7 @@
 # ABSTRACT: Dump the configuration of an application
 
 package App::Cme::Command::dump ;
-$App::Cme::Command::dump::VERSION = '1.019';
+$App::Cme::Command::dump::VERSION = '1.020';
 use strict;
 use warnings;
 use 5.10.1;
@@ -26,6 +26,7 @@ use Data::Dumper;
 
 sub validate_args {
     my ($self, $opt, $args) = @_;
+    $self->check_unknown_args($args);
     $opt->{quiet} = 1; # don't want to mess up yaml output
     $self->process_args($opt,$args);
 }
@@ -36,7 +37,7 @@ sub opt_spec {
         [
             "dumptype=s" => "Dump all values (full) or only customized values",
             {
-                regex => qr/^(?:full|custom)$/,
+                regex => qr/^(?:full|custom|non_upstream_default)$/,
                 default => 'custom'
             }
         ],
@@ -72,7 +73,7 @@ sub execute {
 
     my $dump_string;
     my $format = $opt->{format};
-    my $mode = $opt->{dumptype} eq 'full' ? 'non_upstream_default' : 'custom';
+    my $mode = $opt->{dumptype} || 'custom';
 
     if ($format eq 'cml') {
         $dump_string = $target_node->dump_tree( mode => $mode );
@@ -103,7 +104,7 @@ App::Cme::Command::dump - Dump the configuration of an application
 
 =head1 VERSION
 
-version 1.019
+version 1.020
 
 =head1 SYNOPSIS
 
@@ -122,12 +123,15 @@ By default, dump only custom values, i.e. different from application
 built-in values or model default values. You can use the C<-dumptype> option for
 other types of dump:
 
- -dumptype [ full | custom ]
+ -dumptype [ full | custom | non_upstream_default ]
 
-Choose to dump every values (full) or only customized values (default)
+Choose to dump every values (full), or only customized values (default)
+
+C<non_upstream_default> is like C<full> mode, but value identical with
+application default are omitted. But this should seldom happen.
 
 By default, dump in yaml format. This can be changed in C<JSON>,
-C<Perl>, C<cml> (aka L<Config::Model::Loader> format).
+C<Perl>, C<cml> (aka L<Config::Model::Loader> format) with C<-format> option.
 
 =head1 Common options
 
